@@ -42,7 +42,7 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, DemoData *data)
 		g_signal_handlers_block_by_func (other,
 						 G_CALLBACK (iter_row_changed_cb),
 						 data);
-		gda_data_model_iter_move_at_row (other, row);
+		gda_data_model_iter_move_to_row (other, row);
 		g_signal_handlers_unblock_by_func (other,
 						   G_CALLBACK (iter_row_changed_cb),
 						   data);
